# Autogenerated by nbdev

d = { 'settings': { 'audience': 'Developers',
                'author': 'hchengwang',
                'author_email': 'hchengwang@gmail.com',
                'branch': 'master',
                'company_name': 'ARG @ NYCU',
                'copyright': 'ARG @ NYCU',
                'custom_sidebar': 'False',
                'description': 'A toolset for navigation (no ros) created by arg lab',
                'doc_baseurl': '/arg_robotics_tools/',
                'doc_host': 'https://ARG-NCTU.github.io',
                'doc_path': 'docs',
                'git_url': 'https://github.com/ARG-NCTU/arg_robotics_tools/tree/master/',
                'host': 'github',
                'keywords': 'navi tools utils',
                'language': 'English',
                'lib_name': 'arg_robotics_tools',
                'lib_path': 'arg_robotics_tools',
                'license': 'apache2',
                'min_python': '3.6',
                'nbs_path': '.',
                'recursive': 'False',
                'repo_name': 'arg_robotics_tools',
                'status': '2',
                'title': 'arg_robotics_tools',
                'user': 'ARG-NCTU',
                'version': '0.0.1'},
  'syms': { 'arg_robotics_tools.anchor_logging': { 'arg_robotics_tools.anchor_logging.examine_one_plot': 'https://ARG-NCTU.github.io/arg_robotics_tools/anchor_logging.html#examine_one_plot',
                                                   'arg_robotics_tools.anchor_logging.examine_one_with_boat_plot': 'https://ARG-NCTU.github.io/arg_robotics_tools/anchor_logging.html#examine_one_with_boat_plot',
                                                   'arg_robotics_tools.anchor_logging.examine_plot': 'https://ARG-NCTU.github.io/arg_robotics_tools/anchor_logging.html#examine_plot'},
            'arg_robotics_tools.camera_projection': { 'arg_robotics_tools.camera_projection.camera_projection': 'https://ARG-NCTU.github.io/arg_robotics_tools/camera_projection.html#camera_projection',
                                                      'arg_robotics_tools.camera_projection.camera_projection.apriltag_detection': 'https://ARG-NCTU.github.io/arg_robotics_tools/camera_projection.html#camera_projection.apriltag_detection',
                                                      'arg_robotics_tools.camera_projection.camera_projection.draw_point': 'https://ARG-NCTU.github.io/arg_robotics_tools/camera_projection.html#camera_projection.draw_point',
                                                      'arg_robotics_tools.camera_projection.camera_projection.read_camera_info': 'https://ARG-NCTU.github.io/arg_robotics_tools/camera_projection.html#camera_projection.read_camera_info',
                                                      'arg_robotics_tools.camera_projection.camera_projection.read_images': 'https://ARG-NCTU.github.io/arg_robotics_tools/camera_projection.html#camera_projection.read_images',
                                                      'arg_robotics_tools.camera_projection.camera_projection.solvePnP': 'https://ARG-NCTU.github.io/arg_robotics_tools/camera_projection.html#camera_projection.solvepnp'},
            'arg_robotics_tools.get_ip': { 'arg_robotics_tools.get_ip.device_get_sensors': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#device_get_sensors',
                                           'arg_robotics_tools.get_ip.dp_get_devices': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#dp_get_devices',
                                           'arg_robotics_tools.get_ip.dp_load_config': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#dp_load_config',
                                           'arg_robotics_tools.get_ip.find_duckiepond_devices_yaml': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#find_duckiepond_devices_yaml',
                                           'arg_robotics_tools.get_ip.get_key': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#get_key',
                                           'arg_robotics_tools.get_ip.get_xbee_address': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#get_xbee_address',
                                           'arg_robotics_tools.get_ip.get_xbee_address_boat': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#get_xbee_address_boat',
                                           'arg_robotics_tools.get_ip.ip_connection': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#ip_connection',
                                           'arg_robotics_tools.get_ip.myip': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#myip',
                                           'arg_robotics_tools.get_ip.sensor_get_topic': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#sensor_get_topic',
                                           'arg_robotics_tools.get_ip.ssh_connection': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#ssh_connection',
                                           'arg_robotics_tools.get_ip.ssh_ping_nano': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#ssh_ping_nano',
                                           'arg_robotics_tools.get_ip.ssh_ping_rpi': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#ssh_ping_rpi',
                                           'arg_robotics_tools.get_ip.ssh_rostopic': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#ssh_rostopic',
                                           'arg_robotics_tools.get_ip.test_ping': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#test_ping',
                                           'arg_robotics_tools.get_ip.test_rostopic': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#test_rostopic',
                                           'arg_robotics_tools.get_ip.test_ssh': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#test_ssh',
                                           'arg_robotics_tools.get_ip.test_ssh_intranet': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#test_ssh_intranet',
                                           'arg_robotics_tools.get_ip.whoami': 'https://ARG-NCTU.github.io/arg_robotics_tools/get_ip.html#whoami'},
            'arg_robotics_tools.random_map': { 'arg_robotics_tools.random_map.draw_line': 'https://ARG-NCTU.github.io/arg_robotics_tools/random_map.html#draw_line',
                                               'arg_robotics_tools.random_map.random_generate': 'https://ARG-NCTU.github.io/arg_robotics_tools/random_map.html#random_generate',
                                               'arg_robotics_tools.random_map.sub_random_generate': 'https://ARG-NCTU.github.io/arg_robotics_tools/random_map.html#sub_random_generate'},
            'arg_robotics_tools.robot_model': { 'arg_robotics_tools.robot_model.robot_model_loader': 'https://ARG-NCTU.github.io/arg_robotics_tools/robot_model.html#robot_model_loader',
                                                'arg_robotics_tools.robot_model.robot_model_loader.list_all': 'https://ARG-NCTU.github.io/arg_robotics_tools/robot_model.html#robot_model_loader.list_all',
                                                'arg_robotics_tools.robot_model.robot_model_loader.load': 'https://ARG-NCTU.github.io/arg_robotics_tools/robot_model.html#robot_model_loader.load',
                                                'arg_robotics_tools.robot_model.robot_model_loader.show_link': 'https://ARG-NCTU.github.io/arg_robotics_tools/robot_model.html#robot_model_loader.show_link'},
            'arg_robotics_tools.tsp': { 'arg_robotics_tools.tsp.dist': 'https://ARG-NCTU.github.io/arg_robotics_tools/tsp.html#dist',
                                        'arg_robotics_tools.tsp.distanceGenerate': 'https://ARG-NCTU.github.io/arg_robotics_tools/tsp.html#distancegenerate',
                                        'arg_robotics_tools.tsp.solve_tsp_held_karp': 'https://ARG-NCTU.github.io/arg_robotics_tools/tsp.html#solve_tsp_held_karp',
                                        'arg_robotics_tools.tsp.solve_tsp_nearest_neighbor': 'https://ARG-NCTU.github.io/arg_robotics_tools/tsp.html#solve_tsp_nearest_neighbor',
                                        'arg_robotics_tools.tsp.sortWaypoint': 'https://ARG-NCTU.github.io/arg_robotics_tools/tsp.html#sortwaypoint'},
            'arg_robotics_tools.utils': { 'arg_robotics_tools.utils.gdown_unzip': 'https://ARG-NCTU.github.io/arg_robotics_tools/utils.html#gdown_unzip',
                                          'arg_robotics_tools.utils.pose_dis': 'https://ARG-NCTU.github.io/arg_robotics_tools/utils.html#pose_dis',
                                          'arg_robotics_tools.utils.waypoint': 'https://ARG-NCTU.github.io/arg_robotics_tools/utils.html#waypoint'},
            'arg_robotics_tools.uwb': { 'arg_robotics_tools.uwb.UWB': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb',
                                        'arg_robotics_tools.uwb.UWB.connect': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.connect',
                                        'arg_robotics_tools.uwb.UWB.env_config': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.env_config',
                                        'arg_robotics_tools.uwb.UWB.load_env_config': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.load_env_config',
                                        'arg_robotics_tools.uwb.UWB.localize': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.localize',
                                        'arg_robotics_tools.uwb.UWB.network_id': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.network_id',
                                        'arg_robotics_tools.uwb.UWB.port': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.port',
                                        'arg_robotics_tools.uwb.UWB.pose': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.pose',
                                        'arg_robotics_tools.uwb.UWB.range': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.range',
                                        'arg_robotics_tools.uwb.UWB.write_device': 'https://ARG-NCTU.github.io/arg_robotics_tools/uwb.html#uwb.write_device'},
            'arg_robotics_tools.video2picture': { 'arg_robotics_tools.video2picture.get_images_from_video': 'https://ARG-NCTU.github.io/arg_robotics_tools/video2picture.html#get_images_from_video'},
            'arg_robotics_tools.websocket_rosbridge': { 'arg_robotics_tools.websocket_rosbridge.ros_socket': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket',
                                                        'arg_robotics_tools.websocket_rosbridge.ros_socket.check_connecting': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket.check_connecting',
                                                        'arg_robotics_tools.websocket_rosbridge.ros_socket.get_node': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket.get_node',
                                                        'arg_robotics_tools.websocket_rosbridge.ros_socket.get_topic': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket.get_topic',
                                                        'arg_robotics_tools.websocket_rosbridge.ros_socket.println': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket.println',
                                                        'arg_robotics_tools.websocket_rosbridge.ros_socket.publisher': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket.publisher',
                                                        'arg_robotics_tools.websocket_rosbridge.ros_socket.subscriber': 'https://ARG-NCTU.github.io/arg_robotics_tools/websocket_rosbridge.html#ros_socket.subscriber'},
            'arg_robotics_tools.xbee_coding': { 'arg_robotics_tools.xbee_coding.np_array_to_Odometry': 'https://ARG-NCTU.github.io/arg_robotics_tools/xbee_coding.html#np_array_to_odometry',
                                                'arg_robotics_tools.xbee_coding.xbee_decode': 'https://ARG-NCTU.github.io/arg_robotics_tools/xbee_coding.html#xbee_decode',
                                                'arg_robotics_tools.xbee_coding.xbee_encode': 'https://ARG-NCTU.github.io/arg_robotics_tools/xbee_coding.html#xbee_encode'}}}